/*
    $Id: vpd.h,v 1.3 1999/07/11 01:51:06 james Exp $

    vpd, Granite Communications BS5 Base Station Communication Daemon
    Copyright (C) 1999  James Cameron  (quozl@us.netrek.org)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#define STX  0x02
#define ETX  0x03
#define ACK0 0x06
#define ACK1 0x12
#define DLE  0x10
#define NAK0 0x15
#define NAK1 0x14
#define XOFF 0x13
#define XON  0x11

#define MAXPACKET 8192

struct id
{
    unsigned char id[6];
} base;

/*
**  Commands
*/
static struct bs_clear_log  { unsigned char type; } bs_clear_log={0x22};
static struct bs_disable_rf { unsigned char type; } bs_disable_rf={0x21};
static struct bs_enable_rf  { unsigned char type; } bs_enable_rf={0x23};
static struct bs_test       { unsigned char type; } bs_test={0x24};

static struct bs_initialise_base
{
    unsigned char type;
    unsigned char ladd;
    unsigned short int ltim;
    unsigned char chan; /* zero referenced */
    unsigned char mtim;
} bs_initialise_base={0x25,1,0,4,0};
/* channels 5 6 7 only */

static struct bs_log       { unsigned char type; } bs_log={0x26};

static struct bs_read_memory
{
    unsigned char type;
    unsigned long addr;
    unsigned char cnt;
} bs_read_memory={0x27,0,0};

static struct bs_read_performance_log
{
    unsigned char type;
} bs_read_performance_log={0x28};

static struct bs_reset
{
    unsigned char type;
} bs_reset={0x2b};

static struct bs_send_block
{
    unsigned char type;
    unsigned char tag;
    unsigned char rlun;
    unsigned short int len;
    char pdu;
} __attribute__((packed)) bs_send_block={0x29};

#define BS_SEND_BLOCK_TAG_NORMAL 2
#define BS_SEND_BLOCK_TAG_UNSOLICITED 4

static struct bs_send_multiple
{
    unsigned char type;
    unsigned char map[32];
    unsigned short int len;
    char pdu;
} bs_send_multiple={0x2a};

static struct bs_s
{
    unsigned char type;  /* S */
    unsigned char cmderr;
    unsigned short int cnt;
    char reply;
} bs_s;

/* commands from base to host */

static struct bs_logoff
{
    unsigned char type;
    unsigned char rlun;
    unsigned char src;
} bs_logoff={0x2b};

static struct bs_logon
{
    unsigned char type;
    unsigned char rlun;
    struct id padd;
} bs_logon={0x2c};

static struct bs_rece_block
{
    unsigned char type;
    unsigned char rlun;
    unsigned short int len;
    char pdu;
} bs_rece_block={0x29};

/* send block is also used as a reply */

#define BS_LOGON 0x2c
#define BS_LOGOFF 0x2b
#define BS_RECE_BLOCK 0x29
#define BS_STATUS 'S'

void send_block ( unsigned char rlun, const unsigned char *buffer, unsigned short int length );
